==> nonebot_plugin_trpglogger-0.4.0.tar.gz: nonebot_plugin_trpglogger-0.4.0/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nonebot_plugin_trpglogger']

package_data = \
{'': ['*']}

install_requires = \
['aiofiles>=0.8.0,<0.9.0',
 'httpx>=0.22.0,<0.23.0',
 'nonebot-adapter-onebot>=2.0.0b1,<3.0.0',
 'nonebot2>=2.0.0b1,<3.0.0']

setup_kwargs = {
    'name': 'nonebot-plugin-trpglogger',
    'version': '0.4.0',
    'description': 'a logger for TRPG',
    'long_description': '# TRPG Logger\n\n*基于 [NoneBot2](https://github.com/nonebot/nonebot2) 和 [go-cqhttp](https://github.com/Mrs4s/go-cqhttp) 的 QQ 跑团记录记录器*\n\n[![License](https://img.shields.io/github/license/thereisnodice/TRPGLogger)](LICENSE)\n![Python Version](https://img.shields.io/badge/python-3.7.3+-blue.svg)\n![NoneBot Version](https://img.shields.io/badge/nonebot-2.0.0.a11+-red.svg)\n![PyPI Version](https://img.shields.io/pypi/v/nonebot-plugin-trpglogger.svg)\n\n用来记录跑团记录的 NoneBot2 插件。\n\n## 安装\n\n### 使用 nb-cli（推荐）  \n\n```bash\nnb plugin install nonebot_plugin_trpglogger\n```\n\n### 使用 poetry\n\n```bash\npoetry add nonebot_plugin_trpglogger\n```\n\n## 开始使用\n\n`.log on` 开始记录\n\n`.log off` 停止记录\n\n**一个群同一时间段不能存在两个记录！**\n\n## TODO\n\n- [ ] 暂停记录\n- [ ] 多开记录\n',
    'author': 'Jigsaw',
    'author_email': 'j1g5aw@foxmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/thereisnodice/TRPGLogger',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.3,<4.0.0',
}


setup(**setup_kwargs)

==> nonebot_plugin_trpglogger-0.4.1.tar.gz: nonebot_plugin_trpglogger-0.4.1/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nonebot_plugin_trpglogger']

package_data = \
{'': ['*']}

install_requires = \
['aiofiles>=0.8.0,<0.9.0',
 'httpx>=0.23.1,<1.0.0',
 'nonebot-adapter-onebot>=2.0.0rc1,<3.0.0',
 'nonebot2>=2.0.0rc1,<3.0.0']

setup_kwargs = {
    'name': 'nonebot-plugin-trpglogger',
    'version': '0.4.1',
    'description': 'a logger for TRPG',
    'long_description': '# TRPG Logger\n\n*基于 [NoneBot2](https://github.com/nonebot/nonebot2) 和 [go-cqhttp](https://github.com/Mrs4s/go-cqhttp) 的 QQ 跑团记录记录器*\n\n[![License](https://img.shields.io/github/license/thereisnodice/TRPGLogger)](LICENSE)\n![Python Version](https://img.shields.io/badge/python-3.7.3+-blue.svg)\n![NoneBot Version](https://img.shields.io/badge/nonebot-2.0.0.a11+-red.svg)\n![PyPI Version](https://img.shields.io/pypi/v/nonebot-plugin-trpglogger.svg)\n\n用来记录跑团记录的 NoneBot2 插件。\n\n## 安装\n\n### 使用 nb-cli（推荐）  \n\n```bash\nnb plugin install nonebot_plugin_trpglogger\n```\n\n### 使用 poetry\n\n```bash\npoetry add nonebot_plugin_trpglogger\n```\n\n## 开始使用\n\n`.log on` 开始记录\n\n`.log off` 停止记录\n\n**一个群同一时间段不能存在两个记录！**\n\n## TODO\n\n- [ ] 暂停记录\n- [ ] 多开记录\n',
    'author': 'Jigsaw',
    'author_email': 'j1g5aw@foxmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/thereisnodice/TRPGLogger',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
